Coverage for src/django_resume/plugins/__init__.py: 100%

1 from .registry import plugin_registry

2 from .about import AboutPlugin

3 from .base import SimplePlugin, ListPlugin

4 from .education import EducationPlugin

5 from .identity import IdentityPlugin

6 from .projects import ProjectsPlugin

7 from .skills import SkillsPlugin

8 from .tokens import TokenPlugin

9 from .timelines import EmployedTimelinePlugin, FreelanceTimelinePlugin

10

11

12 __all__ = [

13 "AboutPlugin",

14 "EducationPlugin",

15 "EmployedTimelinePlugin",

16 "FreelanceTimelinePlugin",

17 "IdentityPlugin",

18 "ListPlugin",

19 "plugin_registry",

20 "ProjectsPlugin",

21 "SimplePlugin",

22 "SkillsPlugin",

23 "TokenPlugin",

24]